onElicitationComplete method

Stream<void> onElicitationComplete(
  1. ServerConnection connection
)

Broadcast stream of notifications for this elicitation ID. Events are not buffered so you must listen to this stream prior to opening the URL or you may miss the notification.

Typically you should call .take(1) or .first on this stream to automatically cancel the subscription after receiving the first notification.

Implementation

Stream<void> onElicitationComplete(ServerConnection connection) {
  return connection.onElicitationComplete.where(
    (notification) => notification.elicitationId == elicitationId,
  );
}