Annotations extension type

The annotations for an Annotated object.

on

Constructors

Annotations({List<Role>? audience, DateTime? lastModified, double? priority})
factory
Annotations.fromMap(Map<String, Object?> _value)

Properties

audience → List<Role>?
Describes who the intended customer of this object or data is.
no setter
lastModified → DateTime?
Describes when this data was last modified.
no setter
priority → double?
Describes how important this data is for operating the server.
no setter