blob property
String
get
blob
A base64-encoded string representing the binary data of the item.
Implementation
String get blob => _value[Keys.blob] as String;
A base64-encoded string representing the binary data of the item.
String get blob => _value[Keys.blob] as String;