sampling property
Present if the client supports sampling from an LLM.
Implementation
Map<String, Object?>? get sampling =>
(_value[Keys.sampling] as Map?)?.cast<String, Object?>();
Present if the client supports sampling from an LLM.
Map<String, Object?>? get sampling =>
(_value[Keys.sampling] as Map?)?.cast<String, Object?>();