Completion extension type

An individual completion from a CompleteResult.

on

Constructors

Completion({required List<String> values, int? total, bool? hasMore, Meta? meta})
factory
Completion.fromMap(Map<String, Object?> _value)

Properties

hasMore → bool?
Indicates whether there are additional completion options beyond those provided in the current response, even if the exact total is unknown.
no setter
total → int?
The total number of completion options available.
no setter
values → List<String>
A list of completion values.
no setter