hasMore property

bool? get hasMore

Indicates whether there are additional completion options beyond those provided in the current response, even if the exact total is unknown.

Implementation

bool? get hasMore => _value[Keys.hasMore] as bool?;