value property
String
get
value
The value of the argument to use for completion matching.
Implementation
String get value => _value[Keys.value] as String;
The value of the argument to use for completion matching.
String get value => _value[Keys.value] as String;