model property
String
get
model
The name of the model that generated the message.
Implementation
String get model => _value[Keys.model] as String;
The name of the model that generated the message.
String get model => _value[Keys.model] as String;