content property

Map<String, Object?>? get content

The content of the response, if the user accepted the request.

Must be null if the user didn't accept the request, or if it was a URL-mode elicitation.

The content must conform to the ElicitRequest's requestedSchema in form mode.

Implementation

Map<String, Object?>? get content =>
    _value[Keys.content] as Map<String, Object?>?;