ElicitationCompleteNotification extension type

A notification from the server to the client that a URL elicitation has completed.

on
Implemented types

Constructors

ElicitationCompleteNotification({required String elicitationId, Meta? meta})
factory
ElicitationCompleteNotification.fromMap(Map<String, Object?> _value)

Properties

elicitationId → String
The identifier of the completed elicitation.
no setter
meta → Meta?
This parameter name is reserved by MCP to allow clients and servers to attach additional metadata to their notifications.
no setterinherited

Constants

methodName → const String