EnumValueWithTitle extension type

A const value for an enum schema with an attached title.

on
Implemented types
Available extensions

Constructors

EnumValueWithTitle({required String title, required String constValue})
factory
EnumValueWithTitle.fromMap(Map<String, Object?> _value)

Properties

allOf List<Schema>?
Schema combinator that requires all sub-schemas to match.
no setterinherited
anyOf List<Schema>?
Schema combinator that requires at least one of the sub-schemas to match.
no setterinherited
constValue String
The constant value for this enum entry.
no setter
description String?
A description of this schema.
no setterinherited
not List<Schema>?
Schema combinator that requires none of the sub-schemas to match.
no setterinherited
oneOf List<Schema>?
Schema combinator that requires exactly one of the sub-schemas to match.
no setterinherited
title String
The title for this enum entry.
no setter
type JsonType?
The JsonType of this schema, if present.
no setterinherited

Methods

validate(Object? data) List<ValidationError>

Available on Schema, provided by the SchemaValidation extension

Validates the given data against this schema.