Implementation extension type
Describes the name and version of an MCP implementation.
- on
- Implemented types
Constructors
Properties
- description → String?
-
A human-readable description of what this implementation does.
no setter
-
icons
→ List<
Icon> ? -
Optional set of sized icons that the client can display in a user
interface.
no setter
- name → String
-
Intended for programmatic or logical use, but used as a display name in
past specs for fallback (if title isn't present).
no setterinherited
- title → String?
-
A short title for this object.
no setterinherited
- version → String
-
no setter
- websiteUrl → String?
-
Optional URL to the website of the implementation.
no setter