IntegerSchema extension type

A JSON Schema definition for an int.

on
Implemented types
Available extensions

Constructors

IntegerSchema({String? title, String? description, int? minimum, int? maximum, int? exclusiveMinimum, int? exclusiveMaximum, num? multipleOf})
factory
IntegerSchema.fromMap(Map<String, Object?> _value)

Properties

allOf → List<Schema>?
Schema combinator that requires all sub-schemas to match.
no setterinherited
anyOf → List<Schema>?
Schema combinator that requires at least one of the sub-schemas to match.
no setterinherited
description → String?
A description of this schema.
no setterinherited
exclusiveMaximum → int?
The maximum value (exclusive) for this integer.
no setter
exclusiveMinimum → int?
The minimum value (exclusive) for this integer.
no setter
maximum → int?
The maximum value (inclusive) for this integer.
no setter
minimum → int?
The minimum value (inclusive) for this integer.
no setter
multipleOf → num?
The value must be a multiple of this number.
no setter
not → List<Schema>?
Schema combinator that requires none of the sub-schemas to match.
no setterinherited
oneOf → List<Schema>?
Schema combinator that requires exactly one of the sub-schemas to match.
no setterinherited
title → String?
A title for this schema, should be short.
no setterinherited
type → JsonType?
The JsonType of this schema, if present.
no setterinherited

Methods

validate(Object? data) → List<ValidationError>

Available on Schema, provided by the SchemaValidation extension

Validates the given data against this schema.