MultiSelectEnumSchema extension type

Common properties for multi-select enum schemas.

on
Implemented types
Implementers
Available extensions

Properties

allOf List<Schema>?
Schema combinator that requires all sub-schemas to match.
no setterinherited
anyOf List<Schema>?
Schema combinator that requires at least one of the sub-schemas to match.
no setterinherited
defaultValue Iterable<String>?
Optional default value.
no setter
description String?
A description of this schema.
no setterinherited
isTitledMultiSelect bool
Whether or not this schema looks like a titled multi-select enum.
no setterinherited
isTitledSingleSelect bool
Whether or not this schema looks like a titled single-select enum.
no setterinherited
isUntitledMultiSelect bool
Whether or not this schema looks like an untitled multi-select enum.
no setterinherited
isUntitledSingleSelect bool
Whether or not this schema looks like an untitled single-select enum.
no setterinherited
maxItems int?
The maximum number of items to select.
no setter
minItems int?
The minimum number of items to select.
no setter
not List<Schema>?
Schema combinator that requires none of the sub-schemas to match.
no setterinherited
oneOf List<Schema>?
Schema combinator that requires exactly one of the sub-schemas to match.
no setterinherited
title String?
A title for this schema, should be short.
no setterinherited
type JsonType?
The JsonType of this schema, if present.
no setterinherited

Methods

validate(Object? data) List<ValidationError>

Available on Schema, provided by the SchemaValidation extension

Validates the given data against this schema.