progressToken property

ProgressToken get progressToken

The progress token which was given in the initial request, used to associate this notification with the request that is proceeding.

Implementation

ProgressToken get progressToken =>
    _value[Keys.progressToken] as ProgressToken;