Resource extension type

A known resource that the server is capable of reading.

on
Implemented types

Constructors

Resource({required String uri, required String name, Annotations? annotations, String? description, String? mimeType, int? size, Meta? meta, List<Icon>? icons})
factory
Resource.fromMap(Map<String, Object?> _value)

Properties

annotations → Annotations?
Annotations for this object.
no setterinherited
description → String?
A description of what this resource represents.
no setter
icons → List<Icon>?
Optional set of sized icons that the client can display in a user interface.
no setter
meta → Meta?
The _meta property/parameter is reserved by MCP to allow clients and servers to attach additional metadata to their interactions.
no setterinherited
mimeType → String?
The MIME type of this resource, if known.
no setter
name → String
Intended for programmatic or logical use, but used as a display name in past specs for fallback (if title isn't present).
no setterinherited
size → int?
The size of the raw resource content, in bytes (i.e., before base64 encoding or any tokenization), if known.
no setter
title → String?
A short title for this object.
no setterinherited
uri → String
The URI of this resource.
no setter