tools property
Tools?
get
tools
Present if the server offers any tools to call.
Implementation
Tools? get tools => _value[Keys.tools] as Tools?;
Present if the server offers any tools to call.
Tools? get tools => _value[Keys.tools] as Tools?;