readOnlyHint property
bool?
get
readOnlyHint
If true, the tool does not modify its environment.
Implementation
bool? get readOnlyHint => _value[Keys.readOnlyHint] as bool?;
If true, the tool does not modify its environment.
bool? get readOnlyHint => _value[Keys.readOnlyHint] as bool?;