ToolChoiceMode enum

The tool selection mode for sampling requests.

Inheritance
Available extensions

Values

auto → const ToolChoiceMode

Model decides whether to use tools (default).

require → const ToolChoiceMode

Model MUST use at least one tool before completing.

On the wire, this is represented as "required", but that is a reserved keyword in Dart, so we use "require" instead.

none → const ToolChoiceMode

Model MUST NOT use any tools.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ToolChoiceMode>
A constant List of the values in this enum, in order of their declaration.