UntitledSingleSelectEnumSchema extension type

Schema for single-selection enumeration without display titles for options.

on
Implemented types
Available extensions

Constructors

UntitledSingleSelectEnumSchema({String? title, String? description, String? defaultValue, required Iterable<String> values})
factory
UntitledSingleSelectEnumSchema.fromMap(Map<String, Object?> _value)

Properties

allOf List<Schema>?
Schema combinator that requires all sub-schemas to match.
no setterinherited
anyOf List<Schema>?
Schema combinator that requires at least one of the sub-schemas to match.
no setterinherited
defaultValue String?
The default value for this schema.
no setterinherited
description String?
A description of this schema.
no setterinherited
isTitledMultiSelect bool
Whether or not this schema looks like a titled multi-select enum.
no setterinherited
isTitledSingleSelect bool
Whether or not this schema looks like a titled single-select enum.
no setterinherited
isUntitledMultiSelect bool
Whether or not this schema looks like an untitled multi-select enum.
no setterinherited
isUntitledSingleSelect bool
Whether or not this schema looks like an untitled single-select enum.
no setterinherited
not List<Schema>?
Schema combinator that requires none of the sub-schemas to match.
no setterinherited
oneOf List<Schema>?
Schema combinator that requires exactly one of the sub-schemas to match.
no setterinherited
title String?
A title for this schema, should be short.
no setterinherited
type JsonType?
The JsonType of this schema, if present.
no setterinherited
values Iterable<String>
The allowed enum values.
no setter

Methods

validate(Object? data) List<ValidationError>

Available on Schema, provided by the SchemaValidation extension

Validates the given data against this schema.