onElicitationComplete property
Stream<ElicitationCompleteNotification>
get
onElicitationComplete
Emits an event any time the server sends an elicitation complete notification.
This is a broadcast stream, events are not buffered and only future events are given.
Implementation
Stream<ElicitationCompleteNotification> get onElicitationComplete =>
_elicitationCompleteController.stream;