ConstSchema extension type
A JSON Schema definition for a constant value.
- on
- Implemented types
- Available extensions
Constructors
- ConstSchema({String? title, String? description, required Object? constValue})
-
factory
-
ConstSchema.fromMap(Map<
String, Object?> _value)
Properties
-
allOf
→ List<
Schema> ? -
Schema combinator that requires all sub-schemas to match.
no setterinherited
-
anyOf
→ List<
Schema> ? -
Schema combinator that requires at least one of the sub-schemas to match.
no setterinherited
- constValue → Object?
-
The constant value for this schema.
no setter
- description → String?
-
The description for this constant value.
no setteroverride
-
not
→ List<
Schema> ? -
Schema combinator that requires none of the sub-schemas to match.
no setterinherited
-
oneOf
→ List<
Schema> ? -
Schema combinator that requires exactly one of the sub-schemas to match.
no setterinherited
- title → String?
-
The human readable title for this constant value.
no setteroverride
- type → JsonType?
-
The JsonType of this schema, if present.
no setterinherited
Methods
-
validate(
Object? data) → List< ValidationError> -
Available on Schema, provided by the SchemaValidation extension
Validates the givendataagainst this schema.