Icon extension type
An optionally-sized icon that can be displayed in a user interface.
Constructors
Properties
- mimeType → String?
-
Optional MIME type override if the source MIME type is missing or generic.
no setter
-
sizes
→ List<
String> ? -
Optional array of strings that specify sizes at which the icon can be
used.
no setter
- src → String
-
A standard URI pointing to an icon resource.
no setter
- theme → IconTheme?
-
Optional specifier for the theme this icon is designed for.
no setter