Prompt extension type
A prompt or prompt template that the server offers.
- on
- Implemented types
Constructors
Properties
-
arguments
→ List<
PromptArgument> ? -
A list of arguments to use for templating the prompt.
no setter
- description → String?
-
An optional description of what this prompt provides.
no setter
-
icons
→ List<
Icon> ? -
Optional set of sized icons that the client can display in a user
interface.
no setter
- meta → Meta?
-
The
_metaproperty/parameter is reserved by MCP to allow clients and servers to attach additional metadata to their interactions.no setterinherited - name → String
-
Intended for programmatic or logical use, but used as a display name in
past specs for fallback (if title isn't present).
no setterinherited
- title → String?
-
A short title for this object.
no setterinherited